@@ -74,7 +74,7 @@ def _clean_bag_api_output(api_output: dict) -> List[dict]:
         "gebruiksdoelen",
         "typeAdresseerbaarObject",
         "woonplaatsNaam",
-        "postcode"
+        "postcode",
     ]
 
     items_to_rename = {
@@ -152,6 +152,24 @@ def get_zip_code_info(
     return clean_output
 
 
+def get_additions_form_zip_code_info(zip_code_info: List[dict]) -> List[str]:
+    """Get the additions from the zip code info.
+
+    Returns a list of strings with the additions.
+    If there are no additions, an empty list is returned.
+    If there is at least one addition, but there are less additions
+    than the number of addresses, one addition "nvt" is added.
+    """
+    additions = list()
+    for address in zip_code_info:
+        addition = f"{address['huisletter']}{address['huisnummertoevoeging']}"
+        if addition != "":
+            additions.append(addition)
+    if len(zip_code_info) > len(set(additions)) >= 1:
+        additions.append("nvt")
+    return additions
+
+
 if __name__ == "__main__":
     # postcode = "3011DD"
     # huisnummer = "142"
